from __future__ import annotations

import typing as t
import uuid

from gcs_cli.parsing.types import (
    EXPLICIT_NULL,
    _ExplicitNullClass,
)


def make_associated_flow_policy(
    flow_transfer_source: uuid.UUID | _ExplicitNullClass | None = None,
    flow_transfer_destination: uuid.UUID | _ExplicitNullClass | None = None,
) -> dict[str, t.Any] | None:
    associated_flow_policy: dict[str, t.Any] = {}

    if flow_transfer_source is not None:
        associated_flow_policy["transfer"] = {}

        if flow_transfer_source == EXPLICIT_NULL:
            associated_flow_policy["transfer"]["source"] = None
        else:
            associated_flow_policy["transfer"]["source"] = {
                "flow": flow_transfer_source
            }

    if flow_transfer_destination is not None:
        if not associated_flow_policy:
            associated_flow_policy["transfer"] = {}

        if flow_transfer_destination == EXPLICIT_NULL:
            associated_flow_policy["transfer"]["destination"] = None
        else:
            associated_flow_policy["transfer"]["destination"] = {
                "flow": flow_transfer_destination
            }

    if associated_flow_policy:
        return associated_flow_policy

    return None
