from __future__ import annotations

import uuid

import click

from gcs_cli.helpers import record_print_result_message, requires_login
from gcs_cli.parsing import globus_command
from gcs_cli.services.gcs import get_client


@globus_command(
    "set-subscription-admin-verified",
    short_help="Set the collection subscription admin verified property",
)
@click.argument("COLLECTION_ID", type=click.UUID)
@click.option("--true/--false", "value", default=True)
@requires_login
def collection_set_subscription_admin_verified(
    collection_id: uuid.UUID,
    value: bool,
) -> None:
    """
    Set the subscription_admin_verified property of a collection.

    This command may only be performed by an administrator of the subscription
    associated with this endpoint.
    """
    client = get_client()

    doc = {
        "DATA_TYPE": "subscription_admin_verified#1.0.0",
        "subscription_admin_verified": value,
    }

    res = client.put_subscription_admin_verified(collection_id, data=doc)

    record_print_result_message(res)
