import json
import os
import typing
import uuid

from gcs_cli.commands.user_credentials._common import credential_status
from gcs_cli.helpers import default_identity_id_resolver, requires_login
from gcs_cli.parsing import globus_command, user_credential_id_arg
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, formatted_print
from gcs_cli.services.gcs import get_client


def policy_format_s3(uc: typing.Dict[str, typing.Any]) -> typing.Optional[str]:
    policy = uc["policies"]
    if policy["DATA_TYPE"] != "s3_user_credential_policies#1.2.0":
        return None
    outdoc = {"default key id": policy["s3_key_id"]}
    if "s3_multi_keys" in policy:
        outdoc["s3_multi_keys"] = policy["s3_multi_keys"]
    doc = os.linesep + json.dumps(outdoc, indent=2)
    return doc


@globus_command("show", short_help="Show a User Credential")
@user_credential_id_arg
@requires_login
def cred_show(user_credential_id: uuid.UUID) -> None:
    """
    Show a User Credential on the current Endpoint by ID
    """
    client = get_client()
    res = client.get_user_credential(user_credential_id)
    formatted_print(
        res,
        text_format=FORMAT_TEXT_RECORD,
        fields=[
            ("Credential Name", "display_name"),
            ("Credential ID", "id"),
            ("Local Username", "username"),
            ("Username", default_identity_id_resolver.field),
            ("Status", credential_status),
            ("Policy Details", policy_format_s3),
        ],
    )
