import marshmallow as ma

from .common_collection_schema import CommonCollectionSchema


class GuestCollectionCommonSchema(CommonCollectionSchema):
    """
    Transfer's view of a guest collection
    """

    DATA_TYPE = ma.fields.String(default="shared_endpoint")
    host_path = ma.fields.Constant("/")
    host_endpoint = ma.fields.UUID()
    gcs_mapped_collection_id = ma.fields.UUID(attribute="mapped_collection_id")
    authentication_policy_id = ma.fields.UUID(
        attribute="guest_auth_policy_id", default=None
    )
    skip_auto_delete = ma.fields.Bool(
        default=False,
    )

    guest_collection_activity_notification_policy = ma.fields.Dict(
        attribute="activity_notification_policy",
        # If the model does not provide values for this field, then the schema
        # should default to disabling guest_collection_activity_notification_policy
        # for this guest.
        default={
            "status": [],
            "transfer_use": [],
        },
    )

    @ma.post_dump
    def guest_collection_activity_notification_policy_cleanup(self, obj, **kwargs):
        """
        Transfer will accept:
            guest_collection_activity_notification: null
        Or:
            guest_collection_activity_notification: {
                status: [], # required, can not be null
                transfer_use: [] # required, can not be null
            }

        Transfer requires that the values for status are uppercase and that the
        values for transfer_use are lowercase.
        """
        # "status" is a required field
        if "status" not in obj["guest_collection_activity_notification_policy"]:
            obj["guest_collection_activity_notification_policy"]["status"] = []

        # "transfer_use" is a required field
        if "transfer_use" not in obj["guest_collection_activity_notification_policy"]:
            obj["guest_collection_activity_notification_policy"]["transfer_use"] = []

        # "status" values must be uppercase
        obj["guest_collection_activity_notification_policy"]["status"] = [
            v.upper()
            for v in obj["guest_collection_activity_notification_policy"]["status"]
        ]

        # "transfer_use" values must be lowercase
        obj["guest_collection_activity_notification_policy"]["transfer_use"] = [
            v.lower()
            for v in obj["guest_collection_activity_notification_policy"][
                "transfer_use"
            ]
        ]
        return obj

    @ma.post_dump
    def delete_timeout_if_not_ha(self, obj, **kwargs):
        if not obj.get("high_assurance", False):
            obj.pop("authentication_timeout_mins", None)
        return obj


class GuestCollectionUpdateSchema(GuestCollectionCommonSchema):
    last_accessed_time = ma.fields.DateTime()


class GuestCollectionCreateSchema(GuestCollectionCommonSchema):
    """
    Transfer's view of a guest collection
    """

    gcs_private_uuid = ma.fields.UUID()


guest_collection_create_schema = GuestCollectionCreateSchema()
guest_collection_update_schema = GuestCollectionUpdateSchema()
